<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>padrão</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Ícones</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emoticons</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Habilitar emoticons</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Emoticons animados</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Tema de ícone</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Selecione o tema de emoticons</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Instalar novos emoticons...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Abrir arquivo de tema de ícone</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Instalação falhou</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Arquivo (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Inserir emoticon</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Inserir emoticon</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Inserir emoticon - habilitar em configuração</translation>
    </message>
</context>
</TS>